@@ -23,7 +23,9 @@ use path_slash::PathExt;
 use tracing::{instrument, warn};
 
 use git_branchless_opts::{write_man_pages, InitArgs, InstallManPagesArgs};
-use lib::core::config::{get_default_branch_name, get_default_hooks_dir, get_hooks_dir};
+use lib::core::config::{
+    get_default_branch_name, get_default_hooks_dir, get_main_worktree_hooks_dir,
+};
 use lib::core::dag::Dag;
 use lib::core::effects::Effects;
 use lib::core::eventlog::{EventLogDb, EventReplayer};
@@ -249,12 +251,12 @@ fn install_hooks(effects: &Effects, git_run_info: &GitRunInfo, repo: &Repo) -> e
             .map(|(hook_type, _hook_script)| hook_type)
             .join(", ")
     )?;
-    let hooks_dir = get_hooks_dir(git_run_info, repo, None)?;
+    let hooks_dir = get_main_worktree_hooks_dir(git_run_info, repo, None)?;
     for (hook_type, hook_script) in ALL_HOOKS {
         install_hook(repo, &hooks_dir, hook_type, hook_script)?;
     }
 
-    let default_hooks_dir = get_default_hooks_dir(repo);
+    let default_hooks_dir = get_default_hooks_dir(repo)?;
     if hooks_dir != default_hooks_dir {
         writeln!(
             effects.get_output_stream(),
@@ -281,7 +283,7 @@ fn uninstall_hooks(effects: &Effects, git_run_info: &GitRunInfo, repo: &Repo) ->
             .map(|(hook_type, _hook_script)| hook_type)
             .join(", ")
     )?;
-    let hooks_dir = get_hooks_dir(git_run_info, repo, None)?;
+    let hooks_dir = get_main_worktree_hooks_dir(git_run_info, repo, None)?;
     for (hook_type, _hook_script) in ALL_HOOKS {
         install_hook(
             repo,
@@ -426,7 +428,7 @@ fn install_man_pages(effects: &Effects, repo: &Repo, config: &mut Config) -> eyr
         return Ok(());
     }
 
-    let man_dir = repo.get_man_dir();
+    let man_dir = repo.get_man_dir()?;
     let man_dir_relative = {
         let man_dir_relative = man_dir.strip_prefix(repo.get_path()).wrap_err_with(|| {
             format!(
@@ -534,7 +536,7 @@ fn create_isolated_config(
     repo: &Repo,
     mut parent_config: Config,
 ) -> eyre::Result<Config> {
-    let config_path = repo.get_config_path();
+    let config_path = repo.get_config_path()?;
     let config_dir = config_path
         .parent()
         .ok_or_else(|| eyre::eyre!("Could not get parent config directory"))?;
@@ -575,13 +577,14 @@ fn delete_isolated_config(
     repo: &Repo,
     mut parent_config: Config,
 ) -> eyre::Result<()> {
+    let config_path = repo.get_config_path()?;
     writeln!(
         effects.get_output_stream(),
         "Removing config file: {}",
-        repo.get_config_path().to_string_lossy()
+        config_path.to_string_lossy()
     )?;
     parent_config.remove_multivar("include.path", INCLUDE_PATH_REGEX)?;
-    let result = match std::fs::remove_file(repo.get_config_path()) {
+    let result = match std::fs::remove_file(config_path) {
         Err(err) if err.kind() == std::io::ErrorKind::NotFound => {
             writeln!(
                 effects.get_output_stream(),
