@@ -3,10 +3,8 @@
 
 use std::cmp::Ordering;
 use std::collections::HashMap;
-use std::convert::TryFrom;
 use std::fmt::Debug;
 use std::future::Future;
-use std::iter::FromIterator;
 use std::sync::{Arc, Mutex};
 
 use async_trait::async_trait;
@@ -256,7 +254,7 @@ impl Dag {
 
     #[instrument]
     fn open_inner_dag(repo: &Repo) -> eyre::Result<eden_dag::Dag> {
-        let dag_dir = repo.get_dag_dir();
+        let dag_dir = repo.get_dag_dir()?;
         std::fs::create_dir_all(&dag_dir).wrap_err("Creating .git/branchless/dag dir")?;
         let dag = eden_dag::Dag::open(&dag_dir)
             .wrap_err_with(|| format!("Opening DAG directory at: {:?}", &dag_dir))?;
@@ -419,8 +417,13 @@ impl Dag {
 
     /// Wrapper around DAG method.
     #[instrument]
-    pub fn query_is_ancestor(&self, lhs: NonZeroOid, rhs: NonZeroOid) -> eden_dag::Result<bool> {
-        let result = self.run_blocking(self.inner.is_ancestor(lhs.into(), rhs.into()))?;
+    pub fn query_is_ancestor(
+        &self,
+        ancestor: NonZeroOid,
+        descendant: NonZeroOid,
+    ) -> eden_dag::Result<bool> {
+        let result =
+            self.run_blocking(self.inner.is_ancestor(ancestor.into(), descendant.into()))?;
         Ok(result)
     }
 
@@ -527,6 +530,30 @@ impl Dag {
         })
     }
 
+    /// Determine the connected components among draft commits (commit "stacks")
+    /// that intersect with the provided set.
+    #[instrument]
+    pub fn query_stack_commits(&self, commit_set: CommitSet) -> eyre::Result<CommitSet> {
+        let draft_commits = self.query_draft_commits()?;
+        let stack_roots = self.query_roots(draft_commits.clone())?;
+        let stack_ancestors = self.query_range(stack_roots, commit_set)?;
+        let stack = self
+            // Note that for a graph like
+            //
+            // ```
+            // O
+            // |
+            // o A
+            // | \
+            // |  o B
+            // |
+            // @ C
+            // ```
+            // this will return `{A, B, C}`, not just `{A, C}`.
+            .query_range(stack_ancestors, draft_commits.clone())?;
+        Ok(stack)
+    }
+
     /// Wrapper around DAG method.
     #[instrument]
     pub fn query_all(&self) -> eyre::Result<CommitSet> {
@@ -606,15 +633,19 @@ impl Dag {
 
     /// Wrapper around DAG method.
     #[instrument]
-    pub fn query_only(&self, from: CommitSet, to: CommitSet) -> eden_dag::Result<CommitSet> {
-        let result = self.run_blocking(self.inner.only(from, to))?;
+    pub fn query_only(
+        &self,
+        reachable: CommitSet,
+        unreachable: CommitSet,
+    ) -> eden_dag::Result<CommitSet> {
+        let result = self.run_blocking(self.inner.only(reachable, unreachable))?;
         Ok(result)
     }
 
     /// Wrapper around DAG method.
     #[instrument]
-    pub fn query_range(&self, from: CommitSet, to: CommitSet) -> eden_dag::Result<CommitSet> {
-        let result = self.run_blocking(self.inner.range(from, to))?;
+    pub fn query_range(&self, roots: CommitSet, heads: CommitSet) -> eden_dag::Result<CommitSet> {
+        let result = self.run_blocking(self.inner.range(roots, heads))?;
         Ok(result)
     }
 
