@@ -11,7 +11,7 @@ use rayon::{prelude::*, ThreadPool};
 use tracing::{instrument, warn};
 
 use crate::core::dag::{sorted_commit_set, union_all, CommitSet, Dag};
-use crate::core::effects::{Effects, OperationType};
+use crate::core::effects::{Effects, OperationType, WithProgress};
 use crate::core::formatting::Pluralize;
 use crate::core::rewrite::{RepoPool, RepoResource};
 use crate::core::task::ResourcePool;
@@ -125,20 +125,10 @@ pub enum RebaseCommand {
     },
 }
 
-/// Represents a sequence of commands that can be executed to carry out a rebase
-/// operation.
-#[derive(Debug)]
-pub struct RebasePlan {
-    /// The first commit OID that will be checked out. This is necessary to
-    /// support on-disk rebases.
-    pub first_dest_oid: NonZeroOid,
-
-    /// The commands to run.
-    pub commands: Vec<RebaseCommand>,
-}
-
-impl ToString for RebaseCommand {
-    fn to_string(&self) -> String {
+impl RebaseCommand {
+    /// Convert the command to a string that's used in the `git rebase` plan
+    /// format.
+    pub fn to_rebase_command(&self) -> String {
         match self {
             RebaseCommand::CreateLabel { label_name } => format!("label {label_name}"),
             RebaseCommand::Reset { target } => format!("reset {target}"),
@@ -195,6 +185,18 @@ impl ToString for RebaseCommand {
     }
 }
 
+/// Represents a sequence of commands that can be executed to carry out a rebase
+/// operation.
+#[derive(Debug)]
+pub struct RebasePlan {
+    /// The first commit OID that will be checked out. This is necessary to
+    /// support on-disk rebases.
+    pub first_dest_oid: NonZeroOid,
+
+    /// The commands to run.
+    pub commands: Vec<RebaseCommand>,
+}
+
 /// A token representing that the rebase plan has been checked for validity.
 #[derive(Clone, Debug)]
 pub struct RebasePlanPermissions {
@@ -568,7 +570,7 @@ pub struct RebasePlanBuilder<'a> {
     /// Cache mapping from commit OID to the paths changed in the diff for that
     /// commit. The value is `None` if the commit doesn't have an associated
     /// diff (i.e. is a merge commit).
-    pub(crate) touched_paths_cache: Arc<CHashMap<NonZeroOid, Option<HashSet<PathBuf>>>>,
+    pub(crate) touched_paths_cache: Arc<CHashMap<NonZeroOid, HashSet<PathBuf>>>,
 }
 
 #[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord)]
@@ -1356,7 +1358,6 @@ impl<'a> RebasePlanBuilder<'a> {
         let local_touched_paths: Vec<HashSet<PathBuf>> = touched_commits
             .into_iter()
             .map(|commit| repo.get_paths_touched_by_commit(&commit))
-            .filter_map(|x| x.transpose())
             .try_collect()?;
 
         let filtered_path = {
@@ -1369,12 +1370,15 @@ impl<'a> RebasePlanBuilder<'a> {
             let path: Vec<CacheLookupResult<Option<NonZeroOid>, NonZeroOid>> = {
                 let (effects, progress) = effects.start_operation(OperationType::ReadingFromCache);
                 let _effects = effects;
-                progress.notify_progress(0, path.len());
                 if touched_paths_cache.is_empty() {
                     // Fast path for when the cache hasn't been populated.
-                    path.into_iter().map(CacheLookupResult::NotCached).collect()
+                    path.into_iter()
+                        .with_progress(progress)
+                        .map(CacheLookupResult::NotCached)
+                        .collect()
                 } else {
                     path.into_iter()
+                        .with_progress(progress)
                         .map(|commit_oid| match touched_paths_cache.get(&commit_oid) {
                             Some(upstream_touched_paths) => {
                                 if Self::should_check_patch_id(
@@ -1388,15 +1392,14 @@ impl<'a> RebasePlanBuilder<'a> {
                             }
                             None => CacheLookupResult::NotCached(commit_oid),
                         })
-                        .inspect(|_| progress.notify_progress_inc(1))
                         .collect()
                 }
             };
 
-            let (_effects, progress) = effects.start_operation(OperationType::FilterByTouchedPaths);
-            progress.notify_progress(0, path.len());
-
+            let (effects, progress) = effects.start_operation(OperationType::FilterByTouchedPaths);
+            let _effects = effects;
             pool.install(|| {
+                progress.notify_progress(0, path.len());
                 path.into_par_iter()
                     .map(|commit_oid| {
                         let commit_oid = match commit_oid {
@@ -1435,19 +1438,14 @@ impl<'a> RebasePlanBuilder<'a> {
     }
 
     fn should_check_patch_id(
-        upstream_touched_paths: &Option<HashSet<PathBuf>>,
+        upstream_touched_paths: &HashSet<PathBuf>,
         local_touched_paths: &[HashSet<PathBuf>],
     ) -> bool {
-        match upstream_touched_paths {
-            Some(upstream_touched_paths) => {
-                // It's possible that the same commit was applied after a parent
-                // commit renamed a certain path. In that case, this check won't
-                // trigger. We'll rely on the empty-commit check after the
-                // commit has been made to deduplicate the commit in that case.
-                // FIXME: this code path could be optimized further.
-                local_touched_paths.iter().contains(upstream_touched_paths)
-            }
-            None => true,
-        }
+        // It's possible that the same commit was applied after a parent
+        // commit renamed a certain path. In that case, this check won't
+        // trigger. We'll rely on the empty-commit check after the
+        // commit has been made to deduplicate the commit in that case.
+        // FIXME: this code path could be optimized further.
+        local_touched_paths.iter().contains(upstream_touched_paths)
     }
 }
