@@ -3,7 +3,7 @@ use std::ffi::OsStr;
 use std::string::FromUtf8Error;
 
 use thiserror::Error;
-use tracing::instrument;
+use tracing::{instrument, warn};
 
 use crate::git::config::ConfigRead;
 use crate::git::oid::make_non_zero_oid;
@@ -183,18 +183,6 @@ impl<'a> CategorizedReferenceName<'a> {
         }
     }
 
-    /// Remove the prefix from the reference name. May raise an error if the
-    /// result couldn't be encoded as an `String` (shouldn't happen).
-    #[instrument]
-    pub fn remove_prefix(&self) -> Result<String> {
-        let (name, prefix): (_, &'static str) = match self {
-            Self::LocalBranch { name, prefix } => (name, prefix),
-            Self::RemoteBranch { name, prefix } => (name, prefix),
-            Self::OtherRef { name } => (name, ""),
-        };
-        Ok(name.strip_prefix(prefix).unwrap_or(name).to_owned())
-    }
-
     /// Render the full name of the reference, including its prefix, lossily as
     /// a `String`.
     pub fn render_full(&self) -> String {
@@ -318,6 +306,37 @@ impl<'repo> Branch<'repo> {
         Ok(target_oid)
     }
 
+    /// If this branch tracks a remote ("upstream") branch, return the name of
+    /// that branch without the leading remote name. For example, if the
+    /// upstream branch is `origin/main`, this will return `main`. (Usually,
+    /// this is the same as the name of the local branch, but not always.)
+    pub fn get_upstream_branch_name_without_push_remote_name(
+        &self,
+    ) -> eyre::Result<Option<String>> {
+        let push_remote_name = match self.get_push_remote_name()? {
+            Some(stack_remote_name) => stack_remote_name,
+            None => return Ok(None),
+        };
+        let upstream_branch = match self.get_upstream_branch()? {
+            Some(upstream_branch) => upstream_branch,
+            None => return Ok(None),
+        };
+        let upstream_branch_name = upstream_branch.get_name()?;
+        let upstream_branch_name_without_remote =
+            match upstream_branch_name.strip_prefix(&format!("{push_remote_name}/")) {
+                Some(upstream_branch_name_without_remote) => upstream_branch_name_without_remote,
+                None => {
+                    warn!(
+                        ?push_remote_name,
+                        ?upstream_branch,
+                        "Upstream branch name did not start with push remote name"
+                    );
+                    upstream_branch_name
+                }
+            };
+        Ok(Some(upstream_branch_name_without_remote.to_owned()))
+    }
+
     /// Get the associated remote to push to for this branch. If there is no
     /// associated remote, returns `None`. Note that this never reads the value
     /// of `push.remoteDefault`.
@@ -344,6 +363,18 @@ impl<'repo> Branch<'repo> {
         }
     }
 
+    /// Rename the branch. The new name should not start with `refs/heads`.
+    #[instrument]
+    pub fn rename(&mut self, new_name: &str, force: bool) -> Result<()> {
+        self.inner
+            .rename(new_name, force)
+            .map_err(|err| Error::RenameBranch {
+                source: err,
+                new_name: new_name.to_owned(),
+            })?;
+        Ok(())
+    }
+
     /// Delete the branch.
     #[instrument]
     pub fn delete(&mut self) -> Result<()> {
