@@ -11,7 +11,6 @@
 
 use std::borrow::Borrow;
 use std::collections::{HashMap, HashSet};
-use std::convert::{TryFrom, TryInto};
 use std::num::TryFromIntError;
 use std::ops::Add;
 use std::path::{Path, PathBuf};
@@ -167,6 +166,12 @@ pub enum Error {
         name: ReferenceName,
     },
 
+    #[error("could not rename branch to '{new_name}': {source}")]
+    RenameBranch {
+        source: git2::Error,
+        new_name: String,
+    },
+
     #[error("could not delete branch: {0}")]
     DeleteBranch(#[source] git2::Error),
 
@@ -277,6 +282,8 @@ pub enum Error {
 /// Result type.
 pub type Result<T> = std::result::Result<T, Error>;
 
+pub use git2::ErrorCode as GitErrorCode;
+
 /// Convert a `git2::Error` into an `eyre::Error` with an auto-generated message.
 pub(super) fn wrap_git_error(error: git2::Error) -> eyre::Error {
     eyre::eyre!("Git error {:?}: {}", error.code(), error.message())
@@ -399,9 +406,6 @@ pub enum CreateCommitFastError {
         conflicting_paths: HashSet<PathBuf>,
     },
 
-    #[error("could not get paths touched by commit {commit}")]
-    GetPatch { commit: NonZeroOid },
-
     #[error("could not get conflicts generated by cherry-pick of {commit} onto {onto}: {source}")]
     GetConflicts {
         source: git2::Error,
@@ -519,8 +523,42 @@ impl Repo {
 
     /// Get the path to the working copy for this repository. If the repository
     /// is bare (has no working copy), returns `None`.
-    pub fn get_working_copy_path(&self) -> Option<&Path> {
-        self.inner.workdir()
+    pub fn get_working_copy_path(&self) -> Option<PathBuf> {
+        let workdir = self.inner.workdir()?;
+        if !self.inner.is_worktree() {
+            return Some(workdir.to_owned());
+        }
+
+        // Under some circumstances (not sure exactly when),
+        // `git2::Repository::workdir` on a worktree returns a path like
+        // `/path/to/repo/.git/worktrees/worktree-name/` instead of
+        // `/path/to/worktree/`.
+        let gitdir_file = workdir.join("gitdir");
+        let gitdir = match std::fs::read_to_string(&gitdir_file) {
+            Ok(gitdir) => gitdir,
+            Err(err) if err.kind() == std::io::ErrorKind::NotFound => {
+                return Some(workdir.to_path_buf());
+            }
+            Err(err) => {
+                warn!(
+                    ?workdir,
+                    ?gitdir_file,
+                    ?err,
+                    "gitdir file for worktree could not be read; cannot get workdir path"
+                );
+                return None;
+            }
+        };
+        let gitdir = match gitdir.strip_suffix('\n') {
+            Some(gitdir) => gitdir,
+            None => gitdir.as_str(),
+        };
+        let gitdir = PathBuf::from(gitdir);
+        let workdir = gitdir.parent()?; // remove `.git` suffix
+        std::fs::canonicalize(workdir).ok().or_else(|| {
+            warn!(?workdir, "Failed to canonicalize workdir");
+            None
+        })
     }
 
     /// Get the index file for this repository.
@@ -568,26 +606,41 @@ impl Repo {
         Ok(Config::from(config))
     }
 
+    /// Get the directory where all repo-specific git-branchless state is stored.
+    pub fn get_branchless_dir(&self) -> Result<PathBuf> {
+        let maybe_worktree_parent_repo = self.open_worktree_parent_repo()?;
+        let repo = match maybe_worktree_parent_repo.as_ref() {
+            Some(repo) => repo,
+            None => self,
+        };
+        let dir = repo.get_path().join("branchless");
+        std::fs::create_dir_all(&dir).map_err(|err| Error::CreateBranchlessDir {
+            source: err,
+            path: dir.clone(),
+        })?;
+        Ok(dir)
+    }
+
     /// Get the file where git-branchless-specific Git configuration is stored.
     #[instrument]
-    pub fn get_config_path(&self) -> PathBuf {
-        self.get_path().join("branchless").join("config")
+    pub fn get_config_path(&self) -> Result<PathBuf> {
+        Ok(self.get_branchless_dir()?.join("config"))
     }
 
     /// Get the directory where the DAG for the repository is stored.
     #[instrument]
-    pub fn get_dag_dir(&self) -> PathBuf {
+    pub fn get_dag_dir(&self) -> Result<PathBuf> {
         // Updated from `dag` to `dag2` for `esl01-dag==0.3.0`, since it may
         // not be backwards-compatible.
-        self.get_path().join("branchless").join("dag2")
+        Ok(self.get_branchless_dir()?.join("dag2"))
     }
 
     /// Get the directory to store man-pages. Note that this is the `man`
     /// directory, and not a subsection thereof. `git-branchless` man-pages must
     /// go into the `man/man1` directory to be found by `man`.
     #[instrument]
-    pub fn get_man_dir(&self) -> PathBuf {
-        self.get_path().join("branchless").join("man")
+    pub fn get_man_dir(&self) -> Result<PathBuf> {
+        Ok(self.get_branchless_dir()?.join("man"))
     }
 
     /// Get a directory suitable for storing temporary files.
@@ -597,18 +650,14 @@ impl Repo {
     /// atomically. See
     /// <https://github.com/arxanas/git-branchless/discussions/120>.
     #[instrument]
-    pub fn get_tempfile_dir(&self) -> PathBuf {
-        self.get_path().join("branchless").join("tmp")
+    pub fn get_tempfile_dir(&self) -> Result<PathBuf> {
+        Ok(self.get_branchless_dir()?.join("tmp"))
     }
 
     /// Get the connection to the SQLite database for this repository.
     #[instrument]
     pub fn get_db_conn(&self) -> Result<rusqlite::Connection> {
-        let dir = self.get_path().join("branchless");
-        std::fs::create_dir_all(&dir).map_err(|err| Error::CreateBranchlessDir {
-            source: err,
-            path: dir.clone(),
-        })?;
+        let dir = self.get_branchless_dir()?;
         let path = dir.join("db.sqlite3");
         let conn = rusqlite::Connection::open(&path).map_err(|err| Error::OpenDatabase {
             source: err,
@@ -743,24 +792,22 @@ impl Repo {
     /// If the commit has more than one parent, returns `None`.
     #[instrument]
     pub fn get_patch_for_commit(&self, effects: &Effects, commit: &Commit) -> Result<Option<Diff>> {
-        let changed_paths = match self.get_paths_touched_by_commit(commit)? {
-            None => return Ok(None),
-            Some(changed_paths) => changed_paths,
-        };
+        let changed_paths = self.get_paths_touched_by_commit(commit)?;
         let dehydrated_commit = self.dehydrate_commit(
             commit,
             changed_paths
                 .iter()
-                .map(|x| -> &Path { x })
+                .map(|x| x.as_path())
                 .collect_vec()
                 .as_slice(),
             true,
         )?;
 
-        let parent = dehydrated_commit.get_only_parent();
-        let parent_tree = match &parent {
-            Some(parent) => Some(parent.get_tree()?),
-            None => None,
+        let parent = dehydrated_commit.get_parents();
+        let parent_tree = match parent.as_slice() {
+            [] => None,
+            [parent] => Some(parent.get_tree()?),
+            [..] => return Ok(None),
         };
         let current_tree = dehydrated_commit.get_tree()?;
         let diff = self.get_diff_between_trees(effects, parent_tree.as_ref(), &current_tree, 3)?;
@@ -834,21 +881,27 @@ impl Repo {
     /// If the commit has no parents, returns all of the file paths in that
     /// commit's tree.
     ///
-    /// If the commit has more than one parent, returns `None`.
+    /// If the commit has more than one parent, returns all file paths changed
+    /// with respect to any parent.
     #[instrument]
-    pub fn get_paths_touched_by_commit(&self, commit: &Commit) -> Result<Option<HashSet<PathBuf>>> {
-        let parent_commits = commit.get_parents();
-        let parent_tree = match parent_commits.as_slice() {
-            [] => None,
-            [only_parent] => Some(only_parent.get_tree()?),
-            [..] => return Ok(None),
-        };
-
+    pub fn get_paths_touched_by_commit(&self, commit: &Commit) -> Result<HashSet<PathBuf>> {
         let current_tree = commit.get_tree()?;
-        let changed_paths =
-            get_changed_paths_between_trees(self, parent_tree.as_ref(), Some(&current_tree))
-                .map_err(Error::GetChangedPaths)?;
-        Ok(Some(changed_paths))
+        let parent_commits = commit.get_parents();
+        let changed_paths = if parent_commits.is_empty() {
+            get_changed_paths_between_trees(self, None, Some(&current_tree))
+                .map_err(Error::GetChangedPaths)?
+        } else {
+            let mut result: HashSet<PathBuf> = Default::default();
+            for parent_commit in parent_commits {
+                let parent_tree = parent_commit.get_tree()?;
+                let changed_paths =
+                    get_changed_paths_between_trees(self, Some(&parent_tree), Some(&current_tree))
+                        .map_err(Error::GetChangedPaths)?;
+                result.extend(changed_paths);
+            }
+            result
+        };
+        Ok(changed_paths)
     }
 
     /// Get the patch ID for this commit.
@@ -981,6 +1034,31 @@ impl Repo {
         Ok((snapshot, statuses))
     }
 
+    /// Create a new branch or update an existing one. The provided name should
+    /// be a branch name and not a reference name, i.e. it should not start with
+    /// `refs/heads/`.
+    #[instrument]
+    pub fn create_branch(&self, branch_name: &str, commit: &Commit, force: bool) -> Result<Branch> {
+        if branch_name.starts_with("refs/heads/") {
+            warn!(
+                ?branch_name,
+                "Branch name starts with refs/heads/; this is probably not what you intended."
+            );
+        }
+
+        let branch = self
+            .inner
+            .branch(branch_name, &commit.inner, force)
+            .map_err(|err| Error::CreateBranch {
+                source: err,
+                name: branch_name.to_owned(),
+            })?;
+        Ok(Branch {
+            repo: self,
+            inner: branch,
+        })
+    }
+
     /// Create a new reference or update an existing one.
     #[instrument]
     pub fn create_reference(
@@ -1240,9 +1318,6 @@ impl Repo {
 
         let changed_pathbufs = self
             .get_paths_touched_by_commit(patch_commit)?
-            .ok_or_else(|| CreateCommitFastError::GetPatch {
-                commit: patch_commit.get_oid(),
-            })?
             .into_iter()
             .collect_vec();
         let changed_paths = changed_pathbufs.iter().map(PathBuf::borrow).collect_vec();
@@ -1433,15 +1508,8 @@ impl Repo {
         parent_commit: &Commit,
         opts: &AmendFastOptions,
     ) -> std::result::Result<Tree, CreateCommitFastError> {
-        let parent_commit_pathbufs = self
-            .get_paths_touched_by_commit(parent_commit)?
-            .ok_or_else(|| CreateCommitFastError::GetPatch {
-                commit: parent_commit.get_oid(),
-            })?
-            .into_iter()
-            .collect_vec();
         let changed_paths: Vec<PathBuf> = {
-            let mut result: HashSet<PathBuf> = parent_commit_pathbufs.into_iter().collect();
+            let mut result = self.get_paths_touched_by_commit(parent_commit)?;
             match opts {
                 AmendFastOptions::FromIndex { paths } => result.extend(paths.iter().cloned()),
                 AmendFastOptions::FromWorkingCopy { ref status_entries } => {
@@ -1450,9 +1518,7 @@ impl Repo {
                     }
                 }
                 AmendFastOptions::FromCommit { commit } => {
-                    if let Some(paths) = self.get_paths_touched_by_commit(commit)? {
-                        result.extend(paths.iter().cloned());
-                    }
+                    result.extend(self.get_paths_touched_by_commit(commit)?);
                 }
             };
             result.into_iter().collect_vec()
@@ -1469,17 +1535,18 @@ impl Repo {
         let repo_path = self
             .get_working_copy_path()
             .ok_or(Error::NoWorkingCopyPath)?;
+        let repo_path = &repo_path;
         let new_tree_entries: HashMap<PathBuf, Option<(NonZeroOid, FileMode)>> = match opts {
             AmendFastOptions::FromWorkingCopy { status_entries } => status_entries
                 .iter()
                 .flat_map(|entry| {
                     entry.paths().into_iter().map(
                         move |path| -> Result<(PathBuf, Option<(NonZeroOid, FileMode)>)> {
-                            let file_path = &repo_path.join(&path);
+                            let file_path = repo_path.join(&path);
                             // Try to create a new blob OID based on the current on-disk
                             // contents of the file in the working copy.
                             let entry = self
-                                .create_blob_from_path(file_path)?
+                                .create_blob_from_path(&file_path)?
                                 .map(|oid| (oid, entry.working_copy_file_mode));
                             Ok((path, entry))
                         },
@@ -1516,7 +1583,6 @@ impl Repo {
                     },
                 )?;
                 self.get_paths_touched_by_commit(commit)?
-                    .unwrap_or_default()
                     .iter()
                     .filter_map(|path| match amended_tree.get_path(path) {
                         Ok(Some(entry)) => {
