@@ -1,9 +1,8 @@
 use std::collections::HashMap;
-use std::convert::TryInto;
 use std::ffi::{OsStr, OsString};
 use std::fmt::Write;
 use std::io::{BufRead, BufReader, Read, Write as WriteIo};
-use std::path::{Path, PathBuf};
+use std::path::PathBuf;
 use std::process::{Command, ExitStatus, Stdio};
 use std::sync::Arc;
 use std::thread::{self, JoinHandle};
@@ -11,9 +10,9 @@ use std::thread::{self, JoinHandle};
 use bstr::BString;
 use eyre::{eyre, Context};
 use itertools::Itertools;
-use tracing::instrument;
+use tracing::{instrument, warn};
 
-use crate::core::config::get_hooks_dir;
+use crate::core::config::get_main_worktree_hooks_dir;
 use crate::core::effects::{Effects, OperationType};
 use crate::core::eventlog::{EventTransactionId, BRANCHLESS_TRANSACTION_ID_ENV_VAR};
 use crate::git::repo::Repo;
@@ -256,7 +255,7 @@ impl GitRunInfo {
     ///
     /// This contains additional logic for symlinked `.git` directories to work
     /// around an upstream `libgit2` issue.
-    fn working_directory<'a>(&'a self, repo: &'a Repo) -> &'a Path {
+    fn working_directory<'a>(&'a self, repo: &'a Repo) -> PathBuf {
         repo.get_working_copy_path()
             // `libgit2` returns the working copy path as the parent of the
             // `.git` directory. However, if the `.git` directory is a symlink,
@@ -274,13 +273,13 @@ impl GitRunInfo {
             // root of the working tree.
             .map(|working_copy| {
                 // Both paths are already "canonicalized".
-                if !self.working_directory.starts_with(working_copy) {
-                    &self.working_directory
+                if !self.working_directory.starts_with(&working_copy) {
+                    self.working_directory.clone()
                 } else {
                     working_copy
                 }
             })
-            .unwrap_or_else(|| repo.get_path())
+            .unwrap_or_else(|| repo.get_path().to_owned())
     }
 
     fn run_silent_inner(
@@ -394,8 +393,13 @@ impl GitRunInfo {
         args: &[&str],
         stdin: Option<BString>,
     ) -> eyre::Result<()> {
-        let hook_dir = get_hooks_dir(self, repo, Some(event_tx_id))?;
+        let hook_dir = get_main_worktree_hooks_dir(self, repo, Some(event_tx_id))?;
         if !hook_dir.exists() {
+            warn!(
+                ?hook_dir,
+                ?hook_name,
+                "Git hooks dir did not exist, so could not invoke hook"
+            );
             return Ok(());
         }
 
@@ -413,6 +417,11 @@ impl GitRunInfo {
             if let Some(path) = env.get(OsStr::new("PATH")) {
                 path_components.extend(std::env::split_paths(path));
             }
+            // On windows, PATH's name defaults to "Path".
+            #[cfg(target_os = "windows")]
+            if let Some(path) = env.get(OsStr::new("Path")) {
+                path_components.extend(std::env::split_paths(path));
+            }
             std::env::join_paths(path_components).wrap_err("Joining path components")?
         };
 
