@@ -129,6 +129,25 @@ impl Git {
             })
             .into_owned();
 
+        lazy_static! {
+            // Convert non-empty, blank lines to empty, blank lines to make the
+            // command output easier to use in snapshot assertions.
+            //
+            // Some git output includes lines made up of only whitespace, which
+            // is hard to work with as inline snapshots because editors often
+            // trim such trailing whitespace automatically. In particular,
+            // `git show` prints 4 spaces instead of just an empty line for the
+            // lines between commit message paragraphs. (ie "    \n" instead of
+            // just "\n".)
+            //
+            // This regex targets the output of `git show`, but it could be
+            // generalized in the future if other cases come up.
+            static ref WHITESPACE_ONLY_LINE_RE: Regex = Regex::new(r"(?m)^ {4}$").unwrap();
+        }
+        let output = WHITESPACE_ONLY_LINE_RE
+            .replace_all(&output, "")
+            .into_owned();
+
         Ok(output)
     }
 
@@ -185,6 +204,7 @@ impl Git {
             .collect()
     }
 
+    #[track_caller]
     #[instrument]
     fn run_with_options_inner(
         &self,
@@ -274,6 +294,7 @@ stderr:
     }
 
     /// Run a Git command.
+    #[track_caller]
     pub fn run_with_options<S: AsRef<str> + std::fmt::Debug>(
         &self,
         args: &[S],
@@ -286,6 +307,7 @@ stderr:
     }
 
     /// Run a Git command.
+    #[track_caller]
     pub fn run<S: AsRef<str> + std::fmt::Debug>(
         &self,
         args: &[S],
@@ -310,6 +332,7 @@ stderr:
 
     /// Convenience method to call `branchless_with_options` with the default
     /// options.
+    #[track_caller]
     #[instrument]
     pub fn branchless(&self, subcommand: &str, args: &[&str]) -> eyre::Result<(String, String)> {
         self.branchless_with_options(subcommand, args, &Default::default())
@@ -318,6 +341,7 @@ stderr:
     /// Locate the git-branchless binary and run a git-branchless subcommand
     /// with the provided `GitRunOptions`. These subcommands are located using
     /// `should_use_separate_command_binary`.
+    #[track_caller]
     #[instrument]
     pub fn branchless_with_options(
         &self,
@@ -443,6 +467,18 @@ then you can only run tests in the main `git-branchless` and \
         };
 
         let (_stdout, _stderr) = self.run(args.as_slice())?;
+
+        // Configuration options are not inherited from the original repo, so
+        // set them in the cloned repo.
+        let new_repo = Git {
+            repo_path: target.repo_path.clone(),
+            ..self.clone()
+        };
+        new_repo.init_repo_with_options(&GitInitOptions {
+            make_initial_commit: false,
+            run_branchless_init: false,
+        })?;
+
         Ok(())
     }
 
@@ -497,6 +533,7 @@ then you can only run tests in the main `git-branchless` and \
     /// Commit a file with given contents and message. The `time` argument is
     /// used to set the commit timestamp, which is factored into the commit
     /// hash. The filename is always appended to the message prefix.
+    #[track_caller]
     #[instrument]
     pub fn commit_file_with_contents_and_message(
         &self,
@@ -527,6 +564,7 @@ then you can only run tests in the main `git-branchless` and \
     /// Commit a file with given contents and a default message. The `time`
     /// argument is used to set the commit timestamp, which is factored into the
     /// commit hash.
+    #[track_caller]
     #[instrument]
     pub fn commit_file_with_contents(
         &self,
@@ -539,6 +577,8 @@ then you can only run tests in the main `git-branchless` and \
 
     /// Commit a file with default contents. The `time` argument is used to set
     /// the commit timestamp, which is factored into the commit hash.
+    #[track_caller]
+    #[instrument]
     pub fn commit_file(&self, name: &str, time: isize) -> eyre::Result<NonZeroOid> {
         self.commit_file_with_contents(name, time, &format!("{name} contents\n"))
     }
@@ -618,6 +658,13 @@ then you can only run tests in the main `git-branchless` and \
         Ok(version >= GitVersion(2, 27, 0))
     }
 
+    /// Git v2.44 produces `AUTO_MERGE` refs as part of some operations, which
+    /// changes the event log according to the `reference-transaction` hook.
+    pub fn produces_auto_merge_refs(&self) -> eyre::Result<bool> {
+        let version = self.get_version()?;
+        Ok(version >= GitVersion(2, 44, 0))
+    }
+
     /// Resolve a file during a merge or rebase conflict with the provided
     /// contents.
     #[instrument]
@@ -754,7 +801,12 @@ pub struct GitWorktreeWrapper {
 pub fn make_git_worktree(git: &Git, worktree_name: &str) -> eyre::Result<GitWorktreeWrapper> {
     let temp_dir = tempfile::tempdir()?;
     let worktree_path = temp_dir.path().join(worktree_name);
-    git.run(&["worktree", "add", worktree_path.to_str().unwrap()])?;
+    git.run(&[
+        "worktree",
+        "add",
+        "--detach",
+        worktree_path.to_str().unwrap(),
+    ])?;
     let worktree = Git {
         repo_path: worktree_path,
         ..git.clone()
