@@ -300,7 +300,7 @@ pub struct RecordArgs {
     /// The commit message to use. If not provided, will be prompted to provide a commit message
     /// interactively.
     #[clap(value_parser, short = 'm', long = "message")]
-    pub message: Option<String>,
+    pub messages: Vec<String>,
 
     /// Select changes to include interactively, rather than using the
     /// current staged/unstaged changes.
@@ -320,6 +320,10 @@ pub struct RecordArgs {
     /// if any.
     #[clap(action, short = 'I', long = "insert")]
     pub insert: bool,
+
+    /// After making the new commit, switch back to the previous commit.
+    #[clap(action, short = 's', long = "stash", conflicts_with_all(&["create", "detach"]))]
+    pub stash: bool,
 }
 
 /// Display a nice graph of the commits you've recently worked on.
@@ -341,6 +345,11 @@ pub struct SmartlogArgs {
     #[clap(long)]
     pub reverse: bool,
 
+    /// Don't automatically add HEAD and the main branch to the list of commits
+    /// to present. They will still be added if included in the revset.
+    #[clap(long)]
+    pub exact: bool,
+
     /// Options for resolving revset expressions.
     #[clap(flatten)]
     pub resolve_revset_options: ResolveRevsetOptions,
@@ -383,7 +392,7 @@ pub struct SubmitArgs {
     /// The commits to push. All branches attached to those commits will be
     /// pushed.
     #[clap(value_parser, default_value = "stack()")]
-    pub revset: Revset,
+    pub revsets: Vec<Revset>,
 
     /// Options for resolving revset expressions.
     #[clap(flatten)]
@@ -396,6 +405,11 @@ pub struct SubmitArgs {
     /// An optional message to include with the create or update operation.
     #[clap(short = 'm', long = "message")]
     pub message: Option<String>,
+
+    /// Don't push or create anything. Instead, report what would be pushed or
+    /// created. (Still triggers a fetch.)
+    #[clap(short = 'n', long = "dry-run")]
+    pub dry_run: bool,
 }
 
 /// Run a command on each commit in a given set and aggregate the results.
@@ -443,9 +457,10 @@ pub enum Command {
         #[clap(flatten)]
         resolve_revset_options: ResolveRevsetOptions,
 
-        /// Also delete any branches that are abandoned as a result of this hide.
-        #[clap(action, short = 'D', long = "delete-branches")]
-        delete_branches: bool,
+        /// Don't delete branches that point to commits that would be hidden.
+        /// (Those commits will remain visible as a result.)
+        #[clap(action, long = "no-delete-branches")]
+        no_delete_branches: bool,
 
         /// Also recursively hide all visible children commits of the provided
         /// commits.
