@@ -87,7 +87,7 @@ fn test_query_eval_error() -> eyre::Result<()> {
             },
         )?;
         insta::assert_snapshot!(stderr, @r###"
-        Evaluation error for expression 'foo()': no function with the name 'foo' could be found; these functions are available: all, ancestors, ancestors.nth, author.date, author.email, author.name, branches, children, committer.date, committer.email, committer.name, current, descendants, difference, draft, exactly, heads, intersection, main, message, none, not, only, parents, parents.nth, paths.changed, public, range, roots, siblings, stack, tests.failed, tests.fixable, tests.passed, union
+        Evaluation error for expression 'foo()': no function with the name 'foo' could be found; these functions are available: all, ancestors, ancestors.nth, author.date, author.email, author.name, branches, children, committer.date, committer.email, committer.name, current, descendants, difference, draft, exactly, heads, intersection, main, merges, message, none, not, only, parents, parents.nth, paths.changed, public, range, roots, siblings, stack, tests.failed, tests.fixable, tests.passed, union
         "###);
         insta::assert_snapshot!(stdout, @"");
     }
@@ -185,7 +185,7 @@ fn test_query_hidden_commits() -> eyre::Result<()> {
     let test2_oid = git.commit_file("test2", 2)?;
     git.commit_file("test3", 3)?;
 
-    git.branchless("hide", &["HEAD"])?;
+    git.branchless("hide", &["--no-delete-branches", "HEAD"])?;
     git.run(&["checkout", &test2_oid.to_string()])?;
 
     {
