@@ -13,9 +13,9 @@ fn test_record_unstaged_changes() -> eyre::Result<()> {
     git.commit_file("test1", 1)?;
     git.write_file_txt("test1", "contents1\n")?;
     {
-        let (stdout, _stderr) = git.branchless("record", &["-m", "foo"])?;
+        let (stdout, _stderr) = git.branchless("record", &["-m", "foo", "-m", "bar"])?;
         insta::assert_snapshot!(stdout, @r###"
-        [master 914812a] foo
+        [master 872eae1] foo
          1 file changed, 1 insertion(+), 1 deletion(-)
         "###);
     }
@@ -23,12 +23,14 @@ fn test_record_unstaged_changes() -> eyre::Result<()> {
     {
         let (stdout, _stderr) = git.run(&["show"])?;
         insta::assert_snapshot!(stdout, @r###"
-        commit 914812ae3220add483f11d851dc59f0b5dbdeaa0
+        commit 872eae10daf1e94d0c346540f6d655027c60e7ae
         Author: Testy McTestface <test@example.com>
         Date:   Thu Oct 29 12:34:56 2020 +0000
 
             foo
 
+            bar
+
         diff --git a/test1.txt b/test1.txt
         index 7432a8f..a024003 100644
         --- a/test1.txt
@@ -57,11 +59,13 @@ fn test_record_unstaged_changes_interactive() -> eyre::Result<()> {
         run_in_pty(
             &git,
             "record",
-            &["-i", "-m", "foo"],
+            &["-i", "-m", "initial message"],
             &[
+                PtyAction::WaitUntilContains("initial message"),
                 PtyAction::Write("f"), // expand files
                 PtyAction::WaitUntilContains("contents1"),
                 PtyAction::Write("q"),
+                PtyAction::Write(" "), // confirm quit dialog
             ],
         )?;
     }
@@ -277,6 +281,67 @@ fn test_record_detach() -> eyre::Result<()> {
     Ok(())
 }
 
+#[test]
+fn test_record_stash() -> eyre::Result<()> {
+    let git = make_git()?;
+
+    if !git.supports_reference_transactions()? {
+        return Ok(());
+    }
+    git.init_repo()?;
+
+    git.write_file_txt("test1", "new test1 contents\n")?;
+    git.run(&["add", "test1.txt"])?;
+    {
+        let (stdout, _stderr) = git.branchless("record", &["-m", "foo", "--stash"])?;
+        insta::assert_snapshot!(stdout, @r###"
+        [master 4fe46bd] foo
+         1 file changed, 1 insertion(+)
+         create mode 100644 test1.txt
+        branchless: running command: <git-executable> branch -f master f777ecc9b0db5ed372b2615695191a8a17f79f24
+        branchless: running command: <git-executable> checkout master
+        "###);
+    }
+
+    git.commit_file("test1", 1)?;
+    {
+        let stdout = git.smartlog()?;
+        insta::assert_snapshot!(stdout, @r###"
+        O f777ecc create initial.txt
+        |\
+        | o 4fe46bd foo
+        |
+        @ 62fc20d (> master) create test1.txt
+        "###);
+    }
+
+    git.write_file_txt("test1", "new test1 contents\n")?;
+    {
+        let (stdout, _stderr) = git.branchless("record", &["-m", "foo", "--stash"])?;
+        insta::assert_snapshot!(stdout, @r###"
+        [master 9b6164c] foo
+         1 file changed, 1 insertion(+), 1 deletion(-)
+        branchless: running command: <git-executable> branch -f master 62fc20d2a290daea0d52bdc2ed2ad4be6491010e
+        branchless: running command: <git-executable> checkout master
+        "###);
+    }
+
+    {
+        let stdout = git.smartlog()?;
+        insta::assert_snapshot!(stdout, @r###"
+        O f777ecc create initial.txt
+        |\
+        | o 4fe46bd foo
+        |
+        @ 62fc20d (> master) create test1.txt
+        |
+        o 9b6164c foo
+        "###);
+    }
+
+    Ok(())
+}
+
 #[test]
 fn test_record_create_branch() -> eyre::Result<()> {
     let git = make_git()?;
@@ -633,3 +698,46 @@ fn test_record_binary_contents() -> eyre::Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn test_record_interactive_commit_message_template() -> eyre::Result<()> {
+    let git = make_git()?;
+
+    if !git.supports_reference_transactions()? {
+        return Ok(());
+    }
+    git.init_repo()?;
+
+    git.write_file("commit-template.txt", "This is a commit template!\n")?;
+    git.run(&["config", "commit.template", "commit-template.txt"])?;
+
+    git.commit_file("test1", 1)?;
+    git.detach_head()?;
+    git.write_file_txt("test1", "updated contents\n")?;
+    {
+        let exit_status = run_in_pty(
+            &git,
+            "record",
+            &["-i"],
+            &[
+                PtyAction::WaitUntilContains("test1"),
+                PtyAction::Write(" "),
+                PtyAction::Write("e"),
+                PtyAction::Write("c"),
+            ],
+        )?;
+        assert!(exit_status.success());
+    }
+
+    {
+        let stdout = git.smartlog()?;
+        insta::assert_snapshot!(stdout, @r###"
+        :
+        O 4ab51ca (master) create test1.txt
+        |
+        @ 88e5a87 This is a commit template!
+        "###);
+    }
+
+    Ok(())
+}
