@@ -13,7 +13,7 @@ mod branch_forge;
 pub mod github;
 pub mod phabricator;
 
-use std::collections::{BTreeSet, HashMap, HashSet};
+use std::collections::{BTreeSet, HashMap};
 use std::fmt::{Debug, Write};
 use std::time::SystemTime;
 
@@ -24,12 +24,12 @@ use git_branchless_test::{RawTestOptions, ResolvedTestOptions, Verbosity};
 use github::GithubForge;
 use itertools::Itertools;
 use lazy_static::lazy_static;
-use lib::core::dag::{CommitSet, Dag};
+use lib::core::dag::{union_all, CommitSet, Dag};
 use lib::core::effects::Effects;
 use lib::core::eventlog::{EventLogDb, EventReplayer};
 use lib::core::formatting::{Pluralize, StyledStringBuilder};
 use lib::core::repo_ext::{RepoExt, RepoReferencesSnapshot};
-use lib::git::{GitRunInfo, NonZeroOid, ReferenceName, Repo};
+use lib::git::{GitRunInfo, NonZeroOid, Repo};
 use lib::try_exit_code;
 use lib::util::{ExitCode, EyreExitOr};
 
@@ -38,7 +38,9 @@ use git_branchless_opts::{
 };
 use git_branchless_revset::resolve_commits;
 use phabricator::PhabricatorForge;
-use tracing::{debug, warn};
+use tracing::{debug, info, instrument, warn};
+
+use crate::github::github_push_remote;
 
 lazy_static! {
     /// The style for branches which were successfully submitted.
@@ -53,7 +55,12 @@ lazy_static! {
 /// The status of a commit, indicating whether it needs to be updated remotely.
 #[derive(Clone, Debug)]
 pub enum SubmitStatus {
-    /// The commit exists locally but has not been pushed remotely.
+    /// The commit exists locally and there is no intention to push it to the
+    /// remote.
+    Local,
+
+    /// The commit exists locally and will eventually be pushed to the remote,
+    /// but it has not been pushed yet.
     Unsubmitted,
 
     /// It could not be determined whether the remote commit exists.
@@ -70,11 +77,36 @@ pub enum SubmitStatus {
 /// Information about each commit.
 #[derive(Clone, Debug)]
 pub struct CommitStatus {
+    /// The status of this commit, indicating whether it needs to be updated.
     submit_status: SubmitStatus,
+
+    /// The Git remote associated with this commit, if any.
     remote_name: Option<String>,
-    local_branch_name: Option<String>,
-    #[allow(dead_code)]
-    remote_branch_name: Option<String>,
+
+    /// An identifier corresponding to the commit in the local repository. This
+    /// may be a branch name, a change ID, the commit summary, etc.
+    ///
+    /// This does not necessarily correspond to the commit's name/identifier in
+    /// the forge (e.g. not a code review link); see `remote_commit_name`
+    /// instead.
+    ///
+    /// The calling code will only use this for display purposes, but an
+    /// individual forge implementation can return this from
+    /// `Forge::query_status` and it will be passed back to
+    /// `Forge::create`/`Forge::update`.
+    local_commit_name: Option<String>,
+
+    /// An identifier corresponding to the commit in the remote repository. This
+    /// may be a branch name, a change ID, a code review link, etc.
+    ///
+    /// This does not necessarily correspond to the commit's name/identifier in
+    /// the local repository; see `local_commit_name` instead.
+    ///
+    /// The calling code will only use this for display purposes, but an
+    /// individual forge implementation can return this from
+    /// `Forge::query_status` and it will be passed back to
+    /// `Forge::create`/`Forge::update`.
+    remote_commit_name: Option<String>,
 }
 
 /// Options for submitting commits to the forge.
@@ -115,9 +147,12 @@ pub struct CreateStatus {
     /// (e.g. to include a change ID).
     pub final_commit_oid: NonZeroOid,
 
-    /// The local branch name to use. The caller will try to create the branch
-    /// pointing to that commit (assuming that it doesn't already exist).
-    pub local_branch_name: String,
+    /// An identifier corresponding to the commit, for display purposes only.
+    /// This may be a branch name, a change ID, the commit summary, etc.
+    ///
+    /// This does not necessarily correspond to the commit's name/identifier in
+    /// the forge (e.g. not a code review link).
+    pub local_commit_name: String,
 }
 
 /// "Forge" refers to a Git hosting provider, such as GitHub, GitLab, etc.
@@ -154,34 +189,37 @@ pub fn command_main(ctx: CommandContext, args: SubmitArgs) -> EyreExitOr<()> {
         create,
         draft,
         strategy,
-        revset,
+        revsets,
         resolve_revset_options,
         forge,
         message,
+        dry_run,
     } = args;
     submit(
         &effects,
         &git_run_info,
-        revset,
+        revsets,
         &resolve_revset_options,
         create,
         draft,
         strategy,
         forge,
         message,
+        dry_run,
     )
 }
 
 fn submit(
     effects: &Effects,
     git_run_info: &GitRunInfo,
-    revset: Revset,
+    revsets: Vec<Revset>,
     resolve_revset_options: &ResolveRevsetOptions,
     create: bool,
     draft: bool,
     execution_strategy: Option<TestExecutionStrategy>,
     forge_kind: Option<ForgeKind>,
     message: Option<String>,
+    dry_run: bool,
 ) -> EyreExitOr<()> {
     let repo = Repo::from_current_dir()?;
     let conn = repo.get_db_conn()?;
@@ -197,19 +235,14 @@ fn submit(
         &references_snapshot,
     )?;
 
-    let commit_set = match resolve_commits(
-        effects,
-        &repo,
-        &mut dag,
-        &[revset.clone()],
-        resolve_revset_options,
-    ) {
-        Ok(mut commit_sets) => commit_sets.pop().unwrap(),
-        Err(err) => {
-            err.describe(effects)?;
-            return Ok(Err(ExitCode(1)));
-        }
-    };
+    let commit_set =
+        match resolve_commits(effects, &repo, &mut dag, &revsets, resolve_revset_options) {
+            Ok(commit_sets) => union_all(&commit_sets),
+            Err(err) => {
+                err.describe(effects)?;
+                return Ok(Err(ExitCode(1)));
+            }
+        };
 
     let raw_test_options = RawTestOptions {
         exec: Some("<dummy>".to_string()),
@@ -257,6 +290,7 @@ fn submit(
         message,
     };
 
+    let unioned_revset = Revset(revsets.iter().map(|Revset(inner)| inner).join(" + "));
     let mut forge = select_forge(
         effects,
         git_run_info,
@@ -264,25 +298,36 @@ fn submit(
         &mut dag,
         &event_log_db,
         &references_snapshot,
-        &revset,
+        &unioned_revset,
         forge_kind,
-    );
+    )?;
     let statuses = try_exit_code!(forge.query_status(commit_set)?);
     debug!(?statuses, "Commit statuses");
 
-    let (unsubmitted_commits, commits_to_update, commits_to_skip): (
+    #[allow(clippy::type_complexity)]
+    let (_local_commits, unsubmitted_commits, commits_to_update, commits_to_skip): (
+        HashMap<NonZeroOid, CommitStatus>,
         HashMap<NonZeroOid, CommitStatus>,
         HashMap<NonZeroOid, CommitStatus>,
         HashMap<NonZeroOid, CommitStatus>,
     ) = statuses.into_iter().fold(Default::default(), |acc, elem| {
-        let (mut unsubmitted, mut to_update, mut to_skip) = acc;
+        let (mut local, mut unsubmitted, mut to_update, mut to_skip) = acc;
         let (commit_oid, commit_status) = elem;
         match commit_status {
+            CommitStatus {
+                submit_status: SubmitStatus::Local,
+                remote_name: _,
+                local_commit_name: _,
+                remote_commit_name: _,
+            } => {
+                local.insert(commit_oid, commit_status);
+            }
+
             CommitStatus {
                 submit_status: SubmitStatus::Unsubmitted,
                 remote_name: _,
-                local_branch_name: _,
-                remote_branch_name: _,
+                local_commit_name: _,
+                remote_commit_name: _,
             } => {
                 unsubmitted.insert(commit_oid, commit_status);
             }
@@ -290,8 +335,8 @@ fn submit(
             CommitStatus {
                 submit_status: SubmitStatus::NeedsUpdate,
                 remote_name: _,
-                local_branch_name: _,
-                remote_branch_name: _,
+                local_commit_name: _,
+                remote_commit_name: _,
             } => {
                 to_update.insert(commit_oid, commit_status);
             }
@@ -299,8 +344,8 @@ fn submit(
             CommitStatus {
                 submit_status: SubmitStatus::UpToDate,
                 remote_name: _,
-                local_branch_name: Some(_),
-                remote_branch_name: _,
+                local_commit_name: Some(_),
+                remote_commit_name: _,
             } => {
                 to_skip.insert(commit_oid, commit_status);
             }
@@ -309,82 +354,96 @@ fn submit(
             CommitStatus {
                 submit_status: SubmitStatus::Unknown,
                 remote_name: _,
-                local_branch_name: _,
-                remote_branch_name: _,
+                local_commit_name: _,
+                remote_commit_name: _,
             }
             | CommitStatus {
                 submit_status: SubmitStatus::UpToDate,
                 remote_name: _,
-                local_branch_name: None,
-                remote_branch_name: _,
+                local_commit_name: None,
+                remote_commit_name: _,
             } => {}
         }
-        (unsubmitted, to_update, to_skip)
+        (local, unsubmitted, to_update, to_skip)
     });
 
-    let (created_branches, uncreated_branches): (BTreeSet<String>, BTreeSet<String>) = {
-        let unsubmitted_branches = unsubmitted_commits
+    let (submitted_commit_names, unsubmitted_commit_names): (BTreeSet<String>, BTreeSet<String>) = {
+        let unsubmitted_commit_names: BTreeSet<String> = unsubmitted_commits
             .values()
-            .flat_map(|commit_status| commit_status.local_branch_name.clone())
+            .flat_map(|commit_status| commit_status.local_commit_name.clone())
             .collect();
-        if unsubmitted_commits.is_empty() {
-            Default::default()
-        } else if create {
-            let create_statuses =
-                try_exit_code!(forge.create(unsubmitted_commits, &submit_options)?);
-            let all_branches: HashSet<_> = references_snapshot
-                .branch_oid_to_names
-                .values()
-                .flatten()
-                .collect();
-            let mut created_branches = BTreeSet::new();
-            for (_commit_oid, create_status) in create_statuses {
-                let CreateStatus {
-                    final_commit_oid,
-                    local_branch_name,
-                } = create_status;
-                let branch_reference_name =
-                    ReferenceName::from(format!("refs/heads/{local_branch_name}"));
-                created_branches.insert(local_branch_name);
-                if !all_branches.contains(&branch_reference_name) {
-                    repo.create_reference(
-                        &branch_reference_name,
-                        final_commit_oid,
-                        false,
-                        "submit",
-                    )?;
-                }
-            }
-            (created_branches, Default::default())
+        if create {
+            let created_commit_names = if dry_run {
+                unsubmitted_commit_names.clone()
+            } else {
+                let create_statuses =
+                    try_exit_code!(forge.create(unsubmitted_commits, &submit_options)?);
+                create_statuses
+                    .into_values()
+                    .map(
+                        |CreateStatus {
+                             final_commit_oid: _,
+                             local_commit_name,
+                         }| local_commit_name,
+                    )
+                    .collect()
+            };
+            (created_commit_names, Default::default())
         } else {
-            (Default::default(), unsubmitted_branches)
+            (Default::default(), unsubmitted_commit_names)
         }
     };
 
-    let (updated_branch_names, skipped_branch_names): (BTreeSet<String>, BTreeSet<String>) = {
-        let updated_branch_names = commits_to_update
+    let (updated_commit_names, skipped_commit_names): (BTreeSet<String>, BTreeSet<String>) = {
+        let updated_commit_names = commits_to_update
             .iter()
-            .flat_map(|(_commit_oid, commit_status)| commit_status.local_branch_name.clone())
+            .flat_map(|(_commit_oid, commit_status)| commit_status.local_commit_name.clone())
             .collect();
-        let skipped_branch_names = commits_to_skip
+        let skipped_commit_names = commits_to_skip
             .iter()
-            .flat_map(|(_commit_oid, commit_status)| commit_status.local_branch_name.clone())
+            .flat_map(|(_commit_oid, commit_status)| commit_status.local_commit_name.clone())
             .collect();
 
-        try_exit_code!(forge.update(commits_to_update, &submit_options)?);
-        (updated_branch_names, skipped_branch_names)
+        if !dry_run {
+            try_exit_code!(forge.update(commits_to_update, &submit_options)?);
+        }
+        (updated_commit_names, skipped_commit_names)
     };
 
-    if !created_branches.is_empty() {
+    if !submitted_commit_names.is_empty() {
         writeln!(
             effects.get_output_stream(),
-            "Created {}: {}",
+            "{} {}: {}",
+            if dry_run { "Would submit" } else { "Submitted" },
             Pluralize {
                 determiner: None,
-                amount: created_branches.len(),
-                unit: ("branch", "branches")
+                amount: submitted_commit_names.len(),
+                unit: ("commit", "commits"),
             },
-            created_branches
+            submitted_commit_names
+                .into_iter()
+                .map(|commit_name| effects
+                    .get_glyphs()
+                    .render(
+                        StyledStringBuilder::new()
+                            .append_styled(commit_name, *STYLE_PUSHED)
+                            .build(),
+                    )
+                    .expect("Rendering commit name"))
+                .join(", ")
+        )?;
+    }
+    if !updated_commit_names.is_empty() {
+        writeln!(
+            effects.get_output_stream(),
+            "{} {}: {}",
+            if dry_run { "Would update" } else { "Updated" },
+            Pluralize {
+                determiner: None,
+                amount: updated_commit_names.len(),
+                unit: ("commit", "commits"),
+            },
+            updated_commit_names
                 .into_iter()
                 .map(|branch_name| effects
                     .get_glyphs()
@@ -393,86 +452,69 @@ fn submit(
                             .append_styled(branch_name, *STYLE_PUSHED)
                             .build(),
                     )
-                    .expect("Rendering branch name"))
+                    .expect("Rendering commit name"))
                 .join(", ")
         )?;
     }
-    if !updated_branch_names.is_empty() {
+    if !skipped_commit_names.is_empty() {
         writeln!(
             effects.get_output_stream(),
-            "Pushed {}: {}",
+            "{} {} (already up-to-date): {}",
+            if dry_run { "Would skip" } else { "Skipped" },
             Pluralize {
                 determiner: None,
-                amount: updated_branch_names.len(),
-                unit: ("branch", "branches")
+                amount: skipped_commit_names.len(),
+                unit: ("commit", "commits"),
             },
-            updated_branch_names
+            skipped_commit_names
                 .into_iter()
-                .map(|branch_name| effects
+                .map(|commit_name| effects
                     .get_glyphs()
                     .render(
                         StyledStringBuilder::new()
-                            .append_styled(branch_name, *STYLE_PUSHED)
+                            .append_styled(commit_name, *STYLE_SKIPPED)
                             .build(),
                     )
-                    .expect("Rendering branch name"))
+                    .expect("Rendering commit name"))
                 .join(", ")
         )?;
     }
-    if !skipped_branch_names.is_empty() {
+    if !unsubmitted_commit_names.is_empty() {
         writeln!(
             effects.get_output_stream(),
-            "Skipped {} (already up-to-date): {}",
+            "{} {} (not yet on remote): {}",
+            if dry_run { "Would skip" } else { "Skipped" },
             Pluralize {
                 determiner: None,
-                amount: skipped_branch_names.len(),
-                unit: ("branch", "branches")
+                amount: unsubmitted_commit_names.len(),
+                unit: ("commit", "commits")
             },
-            skipped_branch_names
+            unsubmitted_commit_names
                 .into_iter()
-                .map(|branch_name| effects
+                .map(|commit_name| effects
                     .get_glyphs()
                     .render(
                         StyledStringBuilder::new()
-                            .append_styled(branch_name, *STYLE_SKIPPED)
+                            .append_styled(commit_name, *STYLE_SKIPPED)
                             .build(),
                     )
-                    .expect("Rendering branch name"))
-                .join(", ")
-        )?;
-    }
-    if !uncreated_branches.is_empty() {
-        writeln!(
-            effects.get_output_stream(),
-            "Skipped {} (not yet on remote): {}",
-            Pluralize {
-                determiner: None,
-                amount: uncreated_branches.len(),
-                unit: ("branch", "branches")
-            },
-            uncreated_branches
-                .into_iter()
-                .map(|branch_name| effects
-                    .get_glyphs()
-                    .render(
-                        StyledStringBuilder::new()
-                            .append_styled(branch_name, *STYLE_SKIPPED)
-                            .build(),
-                    )
-                    .expect("Rendering branch name"))
+                    .expect("Rendering commit name"))
                 .join(", ")
         )?;
         writeln!(
             effects.get_output_stream(),
             "\
-These branches were skipped because they were not already associated with a remote repository. To
-create and push them, retry this operation with the --create option."
+These commits {} skipped because they {} not already associated with a remote
+repository. To submit them, retry this operation with the --create option.",
+            if dry_run { "would be" } else { "were" },
+            if dry_run { "are" } else { "were" },
         )?;
     }
 
     Ok(Ok(()))
 }
 
+#[instrument]
 fn select_forge<'a>(
     effects: &'a Effects,
     git_run_info: &'a GitRunInfo,
@@ -481,25 +523,53 @@ fn select_forge<'a>(
     event_log_db: &'a EventLogDb,
     references_snapshot: &'a RepoReferencesSnapshot,
     revset: &'a Revset,
-    forge: Option<ForgeKind>,
-) -> Box<dyn Forge + 'a> {
-    let forge_kind = match forge {
-        Some(forge_kind) => forge_kind,
+    forge_kind: Option<ForgeKind>,
+) -> eyre::Result<Box<dyn Forge + 'a>> {
+    // Check if explicitly set:
+    let forge_kind = match forge_kind {
+        Some(forge_kind) => {
+            info!(?forge_kind, "Forge kind was explicitly set");
+            Some(forge_kind)
+        }
+        None => None,
+    };
+
+    // Check Phabricator:
+    let forge_kind = match forge_kind {
+        Some(forge_kind) => Some(forge_kind),
         None => {
             let use_phabricator = if let Some(working_copy_path) = repo.get_working_copy_path() {
-                working_copy_path.join(".arcconfig").is_file()
+                let arcconfig_path = &working_copy_path.join(".arcconfig");
+                let arcconfig_present = arcconfig_path.is_file();
+                debug!(
+                    ?arcconfig_path,
+                    ?arcconfig_present,
+                    "Checking arcconfig path to decide whether to use Phabricator"
+                );
+                arcconfig_present
             } else {
                 false
             };
-            if use_phabricator {
-                ForgeKind::Phabricator
-            } else {
-                ForgeKind::Branch
-            }
+            use_phabricator.then_some(ForgeKind::Phabricator)
         }
     };
 
-    match forge_kind {
+    // Check Github:
+    let is_github_forge_reliable_enough_for_opt_out_usage = false; // as of 2024-04-06 it's too buggy; see https://github.com/arxanas/git-branchless/discussions/1259
+    let forge_kind = match (
+        forge_kind,
+        is_github_forge_reliable_enough_for_opt_out_usage,
+    ) {
+        (Some(forge_kind), _) => Some(forge_kind),
+        (None, true) => github_push_remote(repo)?.map(|_| ForgeKind::Github),
+        (None, false) => None,
+    };
+
+    // Default:
+    let forge_kind = forge_kind.unwrap_or(ForgeKind::Branch);
+
+    info!(?forge_kind, "Selected forge kind");
+    let forge: Box<dyn Forge> = match forge_kind {
         ForgeKind::Branch => Box::new(BranchForge {
             effects,
             git_run_info,
@@ -515,6 +585,7 @@ fn select_forge<'a>(
             repo,
             dag,
             event_log_db,
+            client: GithubForge::client(git_run_info.clone()),
         }),
 
         ForgeKind::Phabricator => Box::new(PhabricatorForge {
@@ -525,5 +596,6 @@ fn select_forge<'a>(
             event_log_db,
             revset,
         }),
-    }
+    };
+    Ok(forge)
 }
