@@ -19,7 +19,7 @@ use itertools::Itertools;
 use lazy_static::lazy_static;
 use lib::core::check_out::CheckOutCommitOptions;
 use lib::core::dag::{CommitSet, Dag};
-use lib::core::effects::{Effects, OperationType};
+use lib::core::effects::{Effects, OperationType, WithProgress};
 use lib::core::eventlog::EventLogDb;
 use lib::core::formatting::StyledStringBuilder;
 use lib::core::rewrite::{
@@ -307,8 +307,8 @@ impl Forge for PhabricatorForge<'_> {
                         None => SubmitStatus::Unsubmitted,
                     },
                     remote_name: None,
-                    local_branch_name: None,
-                    remote_branch_name: None,
+                    local_commit_name: None,
+                    remote_commit_name: None,
                 };
                 (commit_oid, status)
             })
@@ -389,7 +389,6 @@ Differential Revision: https://phabricator.example.com/D000$(git rev-list --coun
             self.dag,
             self.repo,
             self.event_log_db,
-            event_tx_id,
             self.revset,
             &commits,
             &ResolvedTestOptions {
@@ -536,7 +535,7 @@ Differential Revision: https://phabricator.example.com/D000$(git rev-list --coun
                 commit_oid,
                 CreateStatus {
                     final_commit_oid,
-                    local_branch_name,
+                    local_commit_name: local_branch_name,
                 },
             );
         }
@@ -546,7 +545,7 @@ Differential Revision: https://phabricator.example.com/D000$(git rev-list --coun
             .map(|create_status| {
                 let CreateStatus {
                     final_commit_oid,
-                    local_branch_name: _,
+                    local_commit_name: _,
                 } = create_status;
                 *final_commit_oid
             })
@@ -644,7 +643,6 @@ Differential Revision: https://phabricator.example.com/D000$(git rev-list --coun
             self.dag,
             self.repo,
             self.event_log_db,
-            event_tx_id,
             self.revset,
             &commits,
             &test_options,
@@ -884,8 +882,7 @@ impl PhabricatorForge<'_> {
         // Newly-created commits won't have been observed by the DAG, so add them in manually here.
         let draft_commits = self.dag.query_draft_commits()?.union(newly_created_commits);
 
-        progress.notify_progress(0, commit_oids.len());
-        for commit_oid in commit_oids {
+        for commit_oid in commit_oids.into_iter().with_progress(progress) {
             let id = match self.get_revision_id(commit_oid)? {
                 Some(id) => id,
                 None => {
@@ -931,7 +928,6 @@ impl PhabricatorForge<'_> {
                 Ok(()) => {}
                 Err(exit_code) => return Ok(Err(exit_code)),
             }
-            progress.notify_progress_inc(1);
         }
         Ok(Ok(()))
     }
