@@ -77,7 +77,15 @@ fn render_cursor_smartlog(
     };
 
     let commits = resolve_default_smartlog_commits(effects, repo, &mut dag)?;
-    let graph = make_smartlog_graph(effects, repo, &dag, event_replayer, event_cursor, &commits)?;
+    let graph = make_smartlog_graph(
+        effects,
+        repo,
+        &dag,
+        event_replayer,
+        event_cursor,
+        &commits,
+        false,
+    )?;
     let result = render_graph(
         effects,
         repo,
@@ -754,7 +762,7 @@ fn extract_checkout_target(
                         additional_args: match ref_name {
                             Some(ref_name) => {
                                 let branch_name = CategorizedReferenceName::new(ref_name);
-                                vec!["-B".into(), branch_name.remove_prefix()?.into()]
+                                vec!["-B".into(), branch_name.render_suffix().into()]
                             }
                             None => Default::default(),
                         },
