@@ -17,10 +17,12 @@
 //! Then the branchless workflow may be for you instead.
 
 #![warn(missing_docs)]
-#![warn(clippy::all, clippy::as_conversions, clippy::clone_on_ref_ptr)]
+#![warn(
+    clippy::all,
+    clippy::as_conversions,
+    clippy::clone_on_ref_ptr,
+    clippy::dbg_macro
+)]
 #![allow(clippy::too_many_arguments, clippy::blocks_in_if_conditions)]
 
 pub mod commands;
-pub mod opts;
-pub mod revset;
-pub mod tui;
