@@ -412,6 +412,39 @@ fn test_amend_head() -> eyre::Result<()> {
     Ok(())
 }
 
+#[test]
+fn test_amend_head_with_file_with_space() -> eyre::Result<()> {
+    let git = make_git()?;
+
+    if !git.supports_committer_date_is_author_date()? {
+        return Ok(());
+    }
+
+    git.init_repo()?;
+    git.detach_head()?;
+    git.commit_file("test file with space", 1)?;
+    git.write_file_txt("test file with space", "updated contents")?;
+
+    {
+        let (stdout, _stderr) = git.branchless("amend", &[])?;
+        insta::assert_snapshot!(stdout, @r###"
+        branchless: running command: <git-executable> reset 5ccdda3c1e0dca9aa58634b37cfa9cac09e3975b
+        Amended with 1 uncommitted change.
+        "###);
+    }
+
+    {
+        let stdout = git.smartlog()?;
+        insta::assert_snapshot!(stdout, @r###"
+        O f777ecc (master) create initial.txt
+        |
+        @ 5ccdda3 create test file with space.txt
+        "###);
+    }
+
+    Ok(())
+}
+
 #[test]
 #[cfg(unix)]
 fn test_amend_executable() -> eyre::Result<()> {
@@ -996,6 +1029,9 @@ fn test_amend_no_detach_branch() -> eyre::Result<()> {
 
     git.run(&["checkout", "-b", "foo"])?;
     git.commit_file("test1", 1)?;
+    git.run(&["checkout", "-b", "bar"])?;
+    git.commit_file("test2", 2)?;
+    git.run(&["checkout", "foo"])?;
 
     {
         let stdout = git.smartlog()?;
@@ -1003,6 +1039,8 @@ fn test_amend_no_detach_branch() -> eyre::Result<()> {
         O f777ecc (master) create initial.txt
         |
         @ 62fc20d (> foo) create test1.txt
+        |
+        o 96d1c37 (bar) create test2.txt
         "###);
     }
 
@@ -1013,6 +1051,13 @@ fn test_amend_no_detach_branch() -> eyre::Result<()> {
         insta::assert_snapshot!(stdout, @r###"
         branchless: processing 1 update: branch foo
         branchless: running command: <git-executable> reset foo
+        Attempting rebase in-memory...
+        [1/1] Committed as: fc597fa create test2.txt
+        branchless: processing 1 update: branch bar
+        branchless: processing 1 rewritten commit
+        branchless: running command: <git-executable> checkout foo
+        In-memory rebase succeeded.
+        Restacked 1 commit.
         Amended with 1 uncommitted change.
         "###);
     }
@@ -1023,6 +1068,8 @@ fn test_amend_no_detach_branch() -> eyre::Result<()> {
         O f777ecc (master) create initial.txt
         |
         @ 7143ebc (> foo) create test1.txt
+        |
+        o fc597fa (bar) create test2.txt
         "###);
     }
 
@@ -1135,3 +1182,66 @@ fn test_amend_move_detached_branch() -> eyre::Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn test_amend_merge_commit() -> eyre::Result<()> {
+    let git = make_git()?;
+
+    if !git.supports_reference_transactions()? {
+        return Ok(());
+    }
+    git.init_repo()?;
+    git.detach_head()?;
+    let test1_oid = git.commit_file("test1", 1)?;
+    git.run(&["checkout", "HEAD^"])?;
+    git.commit_file("test2", 2)?;
+    git.run(&["merge", &test1_oid.to_string()])?;
+
+    git.write_file_txt("test1", "new test1 contents\n")?;
+    {
+        let (stdout, _stderr) = git.branchless("amend", &[])?;
+        insta::assert_snapshot!(stdout, @r###"
+        branchless: running command: <git-executable> reset 3ebbc8fdaff7b5d5d0f1101feb3640d06b0297a2
+        Amended with 1 uncommitted change.
+        "###);
+    }
+
+    {
+        let stdout = git.smartlog()?;
+        insta::assert_snapshot!(stdout, @r###"
+        O f777ecc (master) create initial.txt
+        |\
+        | o 62fc20d create test1.txt
+        | & (merge) 3ebbc8f Merge commit '62fc20d2a290daea0d52bdc2ed2ad4be6491010e' into HEAD
+        |
+        o fe65c1f create test2.txt
+        |
+        | & (merge) 62fc20d create test1.txt
+        |/
+        @ 3ebbc8f Merge commit '62fc20d2a290daea0d52bdc2ed2ad4be6491010e' into HEAD
+        "###);
+    }
+
+    {
+        let (stdout, _stderr) = git.run(&["show"])?;
+        insta::assert_snapshot!(stdout, @r###"
+        commit 3ebbc8fdaff7b5d5d0f1101feb3640d06b0297a2
+        Merge: fe65c1f 62fc20d
+        Author: Testy McTestface <test@example.com>
+        Date:   Thu Oct 29 12:34:56 2020 +0000
+
+            Merge commit '62fc20d2a290daea0d52bdc2ed2ad4be6491010e' into HEAD
+
+        diff --cc test1.txt
+        index 0000000,7432a8f..2121042
+        mode 000000,100644..100644
+        --- a/test1.txt
+        +++ b/test1.txt
+        @@@ -1,0 -1,1 +1,1 @@@
+         -test1 contents
+        ++new test1 contents
+        "###);
+    }
+
+    Ok(())
+}
