@@ -314,11 +314,11 @@ fn test_main_branch_not_found_error_message() -> eyre::Result<()> {
 
       ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━ SPANTRACE ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
 
-       0: branchless::core::eventlog::from_event_log_db with effects=<Output fancy=false> repo=<Git repository at: "<repo-path>/.git/"> event_log_db=<EventLogDb>
+       0: branchless::core::eventlog::from_event_log_db with effects=<Output fancy=false> repo=<Git repository at: "<repo-path>/.git/"> event_log_db=<EventLogDb path=Some("<repo-path>/.git/branchless/db.sqlite3")>
           at some/file/path.rs:123
-       1: git_branchless_smartlog::smartlog with effects=<Output fancy=false> git_run_info=<GitRunInfo path_to_git="<git-executable>" working_directory="<repo-path>" env=not shown> options=SmartlogOptions { event_id: None, revset: None, resolve_revset_options: ResolveRevsetOptions { show_hidden_commits: false }, reverse: false }
+       1: git_branchless_smartlog::smartlog with effects=<Output fancy=false> git_run_info=<GitRunInfo path_to_git="<git-executable>" working_directory="<repo-path>" env=not shown> options=SmartlogOptions { event_id: None, revset: None, resolve_revset_options: ResolveRevsetOptions { show_hidden_commits: false }, reverse: false, exact: false }
           at some/file/path.rs:123
-       2: git_branchless_smartlog::command_main with ctx=CommandContext { effects: <Output fancy=false>, git_run_info: <GitRunInfo path_to_git="<git-executable>" working_directory="<repo-path>" env=not shown> } args=SmartlogArgs { event_id: None, revset: None, reverse: false, resolve_revset_options: ResolveRevsetOptions { show_hidden_commits: false } }
+       2: git_branchless_smartlog::command_main with ctx=CommandContext { effects: <Output fancy=false>, git_run_info: <GitRunInfo path_to_git="<git-executable>" working_directory="<repo-path>" env=not shown> } args=SmartlogArgs { event_id: None, revset: None, reverse: false, exact: false, resolve_revset_options: ResolveRevsetOptions { show_hidden_commits: false } }
           at some/file/path.rs:123
 
     Suggestion:
@@ -628,7 +628,7 @@ fn test_init_worktree() -> eyre::Result<()> {
         let stdout = worktree.smartlog()?;
         insta::assert_snapshot!(stdout, @r###"
         :
-        @ 96d1c37 (> new-worktree, master) create test2.txt
+        @ 96d1c37 (master) create test2.txt
         "###);
     }
 
@@ -651,7 +651,7 @@ fn test_install_man_pages() -> eyre::Result<()> {
     insta::assert_snapshot!(man_page_contents, @r###"
     .ie \n(.g .ds Aq \(aq
     .el .ds Aq '
-    .TH git-branchless 1  "git-branchless 0.8.0" 
+    .TH git-branchless 1  "git-branchless 0.9.0" 
     .SH NAME
     git\-branchless \- Branchless workflow for Git
     .SH SYNOPSIS
@@ -759,7 +759,7 @@ fn test_install_man_pages() -> eyre::Result<()> {
     git\-branchless\-help(1)
     Print this message or the help of the given subcommand(s)
     .SH VERSION
-    v0.8.0
+    v0.9.0
     .SH AUTHORS
     Waleed Khan <me@waleedkhan.name>
     "###);
