@@ -136,7 +136,7 @@ fn test_undo_help() -> eyre::Result<()> {
 fn test_undo_navigate() -> eyre::Result<()> {
     let git = make_git()?;
 
-    if !git.supports_reference_transactions()? {
+    if !git.supports_reference_transactions()? || git.produces_auto_merge_refs()? {
         return Ok(());
     }
 
@@ -225,7 +225,7 @@ fn test_undo_navigate() -> eyre::Result<()> {
 fn test_go_to_event() -> eyre::Result<()> {
     let git = make_git()?;
 
-    if !git.supports_reference_transactions()? {
+    if !git.supports_reference_transactions()? || git.produces_auto_merge_refs()? {
         return Ok(());
     }
 
@@ -317,7 +317,6 @@ fn test_undo_hide() -> eyre::Result<()> {
     git.run(&["checkout", "HEAD^"])?;
     git.commit_file("test2", 2)?;
     git.branchless("hide", &["test1"])?;
-    git.run(&["branch", "-D", "test1"])?;
 
     {
         let (stdout, stderr) = git.run(&["smartlog"])?;
@@ -332,7 +331,6 @@ fn test_undo_hide() -> eyre::Result<()> {
     let event_cursor = run_select_past_event(
         &git.get_repo()?,
         vec![
-            CursiveTestingEvent::Event('p'.into()),
             CursiveTestingEvent::Event('p'.into()),
             CursiveTestingEvent::Event(Key::Enter.into()),
             CursiveTestingEvent::Event('y'.into()),
@@ -435,7 +433,12 @@ fn test_undo_move_refs() -> eyre::Result<()> {
 fn test_historical_smartlog_visibility() -> eyre::Result<()> {
     let git = make_git()?;
 
+    if git.produces_auto_merge_refs()? {
+        return Ok(());
+    }
+
     git.init_repo()?;
+    git.detach_head()?;
     git.commit_file("test1", 1)?;
     git.branchless("hide", &["HEAD"])?;
 
@@ -454,9 +457,9 @@ fn test_historical_smartlog_visibility() -> eyre::Result<()> {
     if git.supports_reference_transactions()? {
         insta::assert_snapshot!(screen_to_string(&screenshot1), @r###"
         ┌───────────────────────────────────────────────────┤ Commit graph ├───────────────────────────────────────────────────┐
-        │:                                                                                                                     │
-        │% 62fc20d (manually hidden) (master) create test1.txt                                                                 │
-        │                                                                                                                      │
+        │O f777ecc (master) create initial.txt                                                                                 │
+        │|                                                                                                                     │
+        │% 62fc20d (manually hidden) create test1.txt                                                                          │
         │                                                                                                                      │
         │                                                                                                                      │
         │                                                                                                                      │
@@ -473,16 +476,16 @@ fn test_historical_smartlog_visibility() -> eyre::Result<()> {
         │                                                                                                                      │
         └──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
         ┌──────────────────────────────────────────────────────┤ Events ├──────────────────────────────────────────────────────┐
-        │Repo after transaction 3 (event 4). Press 'h' for help, 'q' to quit.                                                  │
+        │Repo after transaction 5 (event 5). Press 'h' for help, 'q' to quit.                                                  │
         │1. Hide commit 62fc20d create test1.txt                                                                               │
         │                                                                                                                      │
         └──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
         "###);
         insta::assert_snapshot!(screen_to_string(&screenshot2), @r###"
         ┌───────────────────────────────────────────────────┤ Commit graph ├───────────────────────────────────────────────────┐
-        │:                                                                                                                     │
-        │@ 62fc20d (master) create test1.txt                                                                                   │
-        │                                                                                                                      │
+        │O f777ecc (master) create initial.txt                                                                                 │
+        │|                                                                                                                     │
+        │@ 62fc20d create test1.txt                                                                                            │
         │                                                                                                                      │
         │                                                                                                                      │
         │                                                                                                                      │
@@ -499,7 +502,7 @@ fn test_historical_smartlog_visibility() -> eyre::Result<()> {
         │                                                                                                                      │
         └──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
         ┌──────────────────────────────────────────────────────┤ Events ├──────────────────────────────────────────────────────┐
-        │Repo after transaction 2 (event 3). Press 'h' for help, 'q' to quit.                                                  │
+        │Repo after transaction 4 (event 4). Press 'h' for help, 'q' to quit.                                                  │
         │1. Commit 62fc20d create test1.txt                                                                                    │
         │                                                                                                                      │
         └──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
@@ -507,8 +510,9 @@ fn test_historical_smartlog_visibility() -> eyre::Result<()> {
     } else {
         insta::assert_snapshot!(screen_to_string(&screenshot1), @r###"
         ┌───────────────────────────────────────────────────┤ Commit graph ├───────────────────────────────────────────────────┐
-        │:                                                                                                                     │
-        │% 62fc20d (manually hidden) (master) create test1.txt                                                                 │
+        │O f777ecc (master) create initial.txt                                                                                 │
+        │|                                                                                                                     │
+        │% 62fc20d (manually hidden) create test1.txt                                                                          │
         │                                                                                                                      │
         │                                                                                                                      │
         │                                                                                                                      │
@@ -523,36 +527,35 @@ fn test_historical_smartlog_visibility() -> eyre::Result<()> {
         │                                                                                                                      │
         │                                                                                                                      │
         │                                                                                                                      │
+        └──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
+        ┌──────────────────────────────────────────────────────┤ Events ├──────────────────────────────────────────────────────┐
+        │Repo after transaction 3 (event 3). Press 'h' for help, 'q' to quit.                                                  │
+        │1. Hide commit 62fc20d create test1.txt                                                                               │
+        │                                                                                                                      │
+        └──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
+        "###);
+        insta::assert_snapshot!(screen_to_string(&screenshot2), @r###"
+        ┌───────────────────────────────────────────────────┤ Commit graph ├───────────────────────────────────────────────────┐
+        │O f777ecc (master) create initial.txt                                                                                 │
+        │|                                                                                                                     │
+        │@ 62fc20d create test1.txt                                                                                            │
+        │                                                                                                                      │
+        │                                                                                                                      │
+        │                                                                                                                      │
+        │                                                                                                                      │
+        │                                                                                                                      │
+        │                                                                                                                      │
+        │                                                                                                                      │
+        │                                                                                                                      │
+        │                                                                                                                      │
+        │                                                                                                                      │
+        │                                                                                                                      │
+        │                                                                                                                      │
+        │                                                                                                                      │
         │                                                                                                                      │
         └──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
         ┌──────────────────────────────────────────────────────┤ Events ├──────────────────────────────────────────────────────┐
         │Repo after transaction 2 (event 2). Press 'h' for help, 'q' to quit.                                                  │
-        │1. Hide commit 62fc20d create test1.txt                                                                               │
-        │                                                                                                                      │
-        └──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
-        "###);
-        insta::assert_snapshot!(screen_to_string(&screenshot2), @r###"
-        ┌───────────────────────────────────────────────────┤ Commit graph ├───────────────────────────────────────────────────┐
-        │:                                                                                                                     │
-        │@ 62fc20d (master) create test1.txt                                                                                   │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        │                                                                                                                      │
-        └──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
-        ┌──────────────────────────────────────────────────────┤ Events ├──────────────────────────────────────────────────────┐
-        │Repo after transaction 1 (event 1). Press 'h' for help, 'q' to quit.                                                  │
         │1. Commit 62fc20d create test1.txt                                                                                    │
         │                                                                                                                      │
         └──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
@@ -661,6 +664,11 @@ fn test_git_bisect_produces_empty_event() -> eyre::Result<()> {
     if !git.supports_reference_transactions()? {
         return Ok(());
     }
+    if git.get_version()? >= GitVersion(2, 42, 0) {
+        // Later versions of Git write `BISECT_EXPECTED_REV` to the filesystem
+        // as well, causing the below test to fail.
+        return Ok(());
+    }
     git.init_repo()?;
 
     git.commit_file("test1", 1)?;
