@@ -9,7 +9,7 @@ use lib::testing::{make_git, GitRunOptions};
 fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
     let git = make_git()?;
 
-    if !git.supports_reference_transactions()? {
+    if !git.supports_reference_transactions()? || git.produces_auto_merge_refs()? {
         return Ok(());
     }
 
@@ -28,7 +28,8 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
     let event_replayer = EventReplayer::from_event_log_db(&effects, &repo, &event_log_db)?;
     let events: Vec<Event> = get_event_replayer_events(&event_replayer)
         .iter()
-        .map(|event| redact_event_timestamp(event.clone()))
+        .cloned()
+        .map(redact_event_timestamp)
         .collect();
 
     // Bug fixed in Git v2.35: https://github.com/git/git/commit/4866a64508465938b7661eb31afbde305d83e234
@@ -38,7 +39,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
         [
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     1,
                 ),
                 ref_name: ReferenceName(
@@ -50,7 +51,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     2,
                 ),
                 ref_name: ReferenceName(
@@ -62,7 +63,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     3,
                 ),
                 ref_name: ReferenceName(
@@ -74,7 +75,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     3,
                 ),
                 ref_name: ReferenceName(
@@ -86,14 +87,14 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             CommitEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     4,
                 ),
                 commit_oid: NonZeroOid(62fc20d2a290daea0d52bdc2ed2ad4be6491010e),
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     5,
                 ),
                 ref_name: ReferenceName(
@@ -105,7 +106,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     5,
                 ),
                 ref_name: ReferenceName(
@@ -117,14 +118,14 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             CommitEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     6,
                 ),
                 commit_oid: NonZeroOid(96d1c37a3d4363611c49f7e52186e189a04c531f),
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     7,
                 ),
                 ref_name: ReferenceName(
@@ -136,7 +137,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     8,
                 ),
                 ref_name: ReferenceName(
@@ -148,7 +149,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     8,
                 ),
                 ref_name: ReferenceName(
@@ -160,7 +161,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     8,
                 ),
                 ref_name: ReferenceName(
@@ -177,7 +178,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
         [
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     1,
                 ),
                 ref_name: ReferenceName(
@@ -189,7 +190,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     2,
                 ),
                 ref_name: ReferenceName(
@@ -201,7 +202,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     3,
                 ),
                 ref_name: ReferenceName(
@@ -213,7 +214,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     3,
                 ),
                 ref_name: ReferenceName(
@@ -225,14 +226,14 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             CommitEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     4,
                 ),
                 commit_oid: NonZeroOid(62fc20d2a290daea0d52bdc2ed2ad4be6491010e),
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     5,
                 ),
                 ref_name: ReferenceName(
@@ -244,7 +245,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     5,
                 ),
                 ref_name: ReferenceName(
@@ -256,14 +257,14 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             CommitEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     6,
                 ),
                 commit_oid: NonZeroOid(96d1c37a3d4363611c49f7e52186e189a04c531f),
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     7,
                 ),
                 ref_name: ReferenceName(
@@ -275,7 +276,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     8,
                 ),
                 ref_name: ReferenceName(
@@ -287,7 +288,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     8,
                 ),
                 ref_name: ReferenceName(
@@ -299,7 +300,7 @@ fn test_wrap_rebase_in_transaction() -> eyre::Result<()> {
             },
             RefUpdateEvent {
                 timestamp: 0.0,
-                event_tx_id: EventTransactionId(
+                event_tx_id: Id(
                     8,
                 ),
                 ref_name: ReferenceName(
